#!/bin/bash
################################################################################
#                   Thransoft copyLogs Administration Script                   # 
#   Copytight THRANSOFT 14 07 2019 S.D.G. Licence is contained in licence.txt  #
#                To copy logs from tmpfs and keep things tidy                  #
#            It is intended that this script be called from Cron               #
################################################################################
# Configuration
readonly configFile="/etc/copyLogs.config"
if [ ! -f "${configFile}" ]; then
	echo "Cannot read config file! Please check that the path to copyLogs.config is properly configured."
else
	source ${configFile}
fi

readonly banner="CopyLogs: Backup logfiles from local storage to a network mount.
Usage: ./$0 Create a backup with today's datestamp and copy it to SMB.
./$0 -p Purge the network backups of any entry older than deleteThreshold.
./$0 -h Show Help.
Notes: Configuration is edited inside the file itself. This script should only be
run as a cron job."

# Functions defined
function tarMeUp
{
	logName="${logPrefix}$(date +'%d-%b-%Y').tar.gz"
	tar -cpzf /tmp/${logName} -C ${logDir} .
}

function copyLogToSmb 
{
	cp /tmp/${logName} ${smbMount}
	if [ "$?" -eq 0 ]; then
		rm /tmp/${logName}
	else
		echo "Warning: Failure copying log file to $smbMount." 2>&1
		exit 1
	fi
}

# Optional, not recommended: Delete existing logs  in /log (to ensure no duplication)
function cleanLocalLogs
{
	rm -r $logDir/*
	if [ "$?" -ne 0 ]; then
		echo "Failed to delete local logs." 2>&1
	fi
}

# Delete logs in mount older than threshold in days (to ensure it doesn't fill with needless data)
function deleteOldSmbLogs
{
	if [ "$purgeSmb" != "y" ]; then
		echo "Purge SMB is set to off in $0. Thus call to deleteOldSmbLogs aborted." 2>&1
		exit 1
	fi

	earliestLogDate=$(date +'%F' -d "$deleteThreshold days ago")
	find ${smbMount}/${logPrefix}* ! -newermt "${earliestLogDate} 00:00:00" -exec rm -f {} \; 2>&-
}

# Begin execution
while getopts ":hp" opt; do
	case $opt in
		h) echo -e ${banner}; exit 0 ;;
		p) deleteOldSmbLogs; exit 0 ;;
	esac
done
		
tarMeUp
copyLogToSmb

if [ "$cleanLocalLogs" = "y" ]; then
	cleanLocalLogs
fi
